# sisicepy package

[![License: GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://gricad-gitlab.univ-grenoble-alpes.fr/mecaiceige/tools/lib_python/sisicepy/-/blob/main/LICENSE?ref_type=heads)
[![Pipeline Status](https://gricad-gitlab.univ-grenoble-alpes.fr/mecaiceige/tools/lib_python/sisicepy/badges/main/pipeline.svg)](https://gricad-gitlab.univ-grenoble-alpes.fr/mecaiceige/tools/lib_python/sisicepy/-/commits/main)
[![PyPI version](https://badge.fury.io/py/sisicepy.svg)](https://badge.fury.io/py/sisicepy)
[![Website Status](https://img.shields.io/website-up-down-green-red/http/shields.io.svg)](https://sisicepy-mecaiceige-tools-lib-python-05c92b4e528b54a58eeb041fbc.gricad-pages.univ-grenoble-alpes.fr/)

`sisicepy` is a python package to work on sismic data at IGE

## Supported recorder

- [x] [Digos DataCube](https://digos.eu/the-seismic-data-recorder/)

## Supported captor

Supported captor with known ZPK deconvolution. You can use over captor and give the ZPK value

- [x] [Digos geophone](https://digos.eu/geophone/)
- [x] [Geobit C100](https://geobit-instruments.com/seismometers-seismic-sensors/)
- [x] [Geobit S100](https://geobit-instruments.com/seismometers-seismic-sensors/)
